@@ -1,4 +1,4 @@
-/* $Id: first.c,v 1.34.4.2.2.1 2002/01/14 00:56:50 baddog Exp $ */
+/* $Id: first.c,v 1.45 2003/10/20 15:19:36 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -26,7 +26,6 @@
 #include <glibtop.h>
 #include <glibtop/open.h>
 #include <glibtop/close.h>
-#include <glibtop/xmalloc.h>
 
 #include <glibtop/parameter.h>
 
@@ -232,7 +231,7 @@ main (int argc, char *argv [])
 		printf ("\n");
 	}
 
-	glibtop_free (ptr);
+	g_free (ptr);
 
 	pid = getpid ();
 	ppid = getppid ();
@@ -346,7 +345,7 @@ main (int argc, char *argv [])
 		(unsigned long) data.proc_args.size,
 		args ? args : "");
 
-	glibtop_free (args);
+	g_free (args);
 
 	printf ("\n");
 
@@ -456,7 +455,7 @@ main (int argc, char *argv [])
 		(unsigned long) data.proc_args.size,
 		args ? args : "");
 
-	glibtop_free (args);
+	g_free (args);
 
 	printf ("\n");
 
@@ -567,7 +566,7 @@ main (int argc, char *argv [])
 		(unsigned long) data.proc_args.size,
 		args ? args : "");
 
-	glibtop_free (args);
+	g_free (args);
 
 	glibtop_close ();
 
