@@ -1,4 +1,4 @@
-/* $Id: proclist.c,v 1.21 2003/10/19 16:55:39 carlos Exp $ */
+/* $Id: proclist.c,v 1.23 2003/10/20 15:19:56 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -22,7 +22,6 @@
 */
 
 #include <config.h>
-#include <glibtop/xmalloc.h>
 #include <glibtop/proclist.h>
 
 #include <glibtop/procuid.h>
@@ -171,15 +170,14 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 		 * full, we copy it to the pids_chain. */
 
 		if (count >= BLOCK_COUNT) {
-			/* The following call to glibtop_realloc will be
-			 * equivalent to glibtop_malloc () if `pids_chain' is
+			/* The following call to g_realloc will be
+			 * equivalent to g_malloc () if `pids_chain' is
 			 * NULL. We just calculate the new size and copy `pids'
 			 * to the beginning of the newly allocated block. */
 
 			new_size = pids_size + BLOCK_SIZE;
 
-			pids_chain = glibtop_realloc_r
-				(server, pids_chain, new_size);
+			pids_chain = g_realloc (pids_chain, new_size);
 
 			memcpy (pids_chain + pids_offset, pids, BLOCK_SIZE);
 
@@ -204,14 +202,14 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 
 	if (!count) return NULL;
 
-	/* The following call to glibtop_realloc will be equivalent to
-	 * glibtop_malloc if pids_chain is NULL. We just calculate the
+	/* The following call to g_realloc will be equivalent to
+	 * g_malloc if pids_chain is NULL. We just calculate the
 	 * new size and copy pids to the beginning of the newly allocated
 	 * block. */
 	
 	new_size = pids_size + count * sizeof (unsigned);
 	
-	pids_chain = glibtop_realloc_r (server, pids_chain, new_size);
+	pids_chain = g_realloc (pids_chain, new_size);
 	
 	memcpy (pids_chain + pids_offset, pids, count * sizeof (unsigned));
 	
